summaryrefslogtreecommitdiffstats
path: root/kioslaves/mbox/readmbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kioslaves/mbox/readmbox.h')
-rw-r--r--kioslaves/mbox/readmbox.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kioslaves/mbox/readmbox.h b/kioslaves/mbox/readmbox.h
index 0f7c4d836..ea63068ca 100644
--- a/kioslaves/mbox/readmbox.h
+++ b/kioslaves/mbox/readmbox.h
@@ -40,11 +40,11 @@ public:
* Constructor
*
* @param info The information of the file to read
* @param parent The instance of the parent MBoxProtocol.
* @param onlynew Only read new messages from the MBox file.
* @param savetime If true, the atime of the mbox-file is preserved (note that this touch the ctime).
*/
- ReadMBox( const UrlInfo* info, MBoxProtocol* parent, bool onlynew = false, bool savetime = false );
+ ReadMBox( const UrlInfo* info, MBoxProtocol* tqparent, bool onlynew = false, bool savetime = false );
/**
* Destructor
@@ -53,14 +53,14 @@ public:
/**
* This functions return the current line
- * @return The line last read, or TQString::null if there wasn't such last line
+ * @return The line last read, or TQString() if there wasn't such last line
*/
TQString currentLine() const;
/**
* This function returns the current id. The id is the first line of an email,
* and is used in filenaming. The id normally starts with "From ".
- * @return The current ID, or TQString::null if no id was found yet.
+ * @return The current ID, or TQString() if no id was found yet.
*/
TQString currentID() const;
@@ -40,11 +40,11 @@ public:
*
* @param info The information of the file to read
- * @param parent The instance of the parent MBoxProtocol.
+ * @param tqparent The instance of the tqparent MBoxProtocol.
* @param onlynew Only read new messages from the MBox file.
* @param savetime If true, the atime of the mbox-file is preserved (note that this touch the ctime).